# geodev


[![image](https://img.shields.io/pypi/v/geodev.svg)](https://pypi.python.org/pypi/geodev)
[![image](https://img.shields.io/conda/vn/conda-forge/geodev.svg)](https://anaconda.org/conda-forge/geodev)


**A python package for geospatial analysis and mapping**


-   Free software: MIT License
-   Documentation: https://jope65.github.io/geodev
    

## Features

-   TODO
